==> haskell-text-zipper-0.11-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-zipper
version:              0.11
visibility:           public
id:                   text-zipper-0.11-HT8HMaymDAr7fiUo0mRGYz
key:                  text-zipper-0.11-HT8HMaymDAr7fiUo0mRGYz
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  d0d12c1868d8018b8f92d234c1630d7e
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.0.1/site-local/text-zipper-0.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/text-zipper-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/text-zipper-0.11
hs-libraries:         HStext-zipper-0.11-HT8HMaymDAr7fiUo0mRGYz
depends:
    base-4.15.0.0 deepseq-1.4.5.0 text-1.2.4.1
    vector-0.12.3.1-4LU8STmHsbh153eRU0hKX2

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-zipper-0.11-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-zipper
version:              0.11
visibility:           public
id:                   text-zipper-0.11-3Tro6MBoIfr9fiTmKTDc4v
key:                  text-zipper-0.11-3Tro6MBoIfr9fiTmKTDc4v
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  263f07e6bb470c9c5561666500423d09
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.0.1/site-local/text-zipper-0.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/text-zipper-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/text-zipper-0.11
hs-libraries:         HStext-zipper-0.11-3Tro6MBoIfr9fiTmKTDc4v
depends:
    base-4.15.0.0 deepseq-1.4.5.0 text-1.2.4.1
    vector-0.12.3.1-1QSAcoQ4BjrEDZahKaKVTn

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
